@@ -20,11 +20,6 @@
    
 */
                             
-
-
-
-
-
 #ifndef DXEMU_H
 #define DXEMU_H
 
@@ -33,13 +28,23 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "gettext.h"
+#include <iostream>
+#include <map>
+#include <vector>
+#include <string>
+using namespace std;
+
+typedef multimap <string, vector<int> > MMAP_CHORD;
+
+// MMAP_CHORD midi2chordtable;
+
 #define POLY 11
 #define TICKS_PER_QUARTER 128
 #define TICKS4 896
 #define MAGIC_FILE 0x4d546864
 #define MAGIC_TRACK 0x4d54726b
 
-
+void Chordload(string Chordsymbol,vector<int> MidiIntervals);
 extern int Pexitprogram, espera, programa,vum,vumvum,tum,cambialo;
 extern int vavi,pr,pr1,count,ulcount,canaledit;
 extern char NombreAcorde[16];
@@ -53,9 +58,8 @@ extern int actunex,ponfin,ttnp,tocadrum,sde,sdec,paraplay;
 extern int TempoSong,SNomi,cambiapat,InvMode;
 extern int splash,splashcounter,clicksplash,lastcasdr,cambiacasdr;
 extern int lastcascr,cambiacascr;
+
 extern struct song
-
-
 {
  int a;
  int b;
@@ -79,10 +83,7 @@ extern struct song
  int ar16;
 } S[129];
 
- 
-
-
-
+// ********************************************************************************************************
 
 class GMO
 
@@ -95,7 +96,8 @@ public:
    void midievents (int i);
    void miramidi();
    void panico(int data, int canales);
-   void MiraChord();
+//   void MiraChord();
+   void ChangeChord();
    void enviomidi(int i, int fchout);
    void enviocontrol(int i, int j, int fchout);
    void organo();
@@ -112,7 +114,9 @@ public:
    void clear_queue();
    snd_seq_tick_time_t get_tick();
    void loadfile(char *filename);
+   void loadsound(char *filename);
    void savefile(char *filename);   
+   void savesoundfile(int soundno, char *filename);   
    void loadstyl(char *filename);
    void savestyl(char *filename);   
    void savevelo(char *filename);
@@ -180,6 +184,23 @@ public:
    void GetCombiM(int i);
 
 
+  int v1highMidi;
+  int v1lowMidi;
+  int v1highVelocity;
+  int v1lowVelocity;
+  int v2highMidi;
+  int v2lowMidi;
+  int v2highVelocity;
+  int v2lowVelocity;
+  int v3highMidi;
+  int v3lowMidi;
+  int v3highVelocity;
+  int v3lowVelocity;
+  int v4highMidi;
+  int v4lowMidi;
+  int v4highVelocity;
+  int v4lowVelocity;
+
   int solo[12];     
   char Delacorde[16];
   int cambiaacorde;      
@@ -341,9 +362,11 @@ public:
   int rnote[POLY];
   int gate[POLY];
   char Name[30];
+
   int progch[12], volume[12], BankLSB[12],BankMSB[12], pan[12], Pon[12];
   int reverb[12], chorus[12], Ptime[12], OnOff[12], detune[12];
   int octa[12];
+
   int pmidi_in;
   int pmidi_out;
   int queue_id; 
@@ -370,7 +393,7 @@ public:
   int di4;
   int pafuera;
   int qcontrol;
-  int d1,d2,d3,d4;
+  int d1,d2,d3,d4,d5,d6,d7,d8;
   int genwindow;      
   int NumVari[20];  
   char ElEstilo[32];
@@ -625,6 +648,12 @@ struct Ritmo
 
 } Rt[500];
       
+struct TipoCh
+{
+int ter;
+int qui;
+int sep;
+} TCh[11];
 
 struct NomChord
 {
@@ -638,17 +667,6 @@ struct NomChordExtended
  int  note; 
 } NCE[20];
 
-
-struct TipoCh
-
-{
-int ter;
-int qui;
-int sep;
-
-} TCh[11];
-
-
 struct Ch3
 
 {
@@ -662,7 +680,6 @@ struct Ch3
 } Chord3[12];
 
 struct Ch4
-
 {
   int tipo;
   int fund;
@@ -688,7 +705,6 @@ struct Ch5
   char Nom[10];
 } Chord5[11];
      
-
     
   char temporal[8]; 
   char tempoch[8];    
@@ -792,10 +808,8 @@ struct MasterTempoData
 
 } TemT[200];
 
-
-
-
-
+//rlv *************************
+int globalchannel;
 
 };
 
